@@ -1,5 +1,4 @@
-import sys
 from ansible_vault.cli import main
 
 
-sys.exit(main())
+raise SystemExit(main())
